# xlsxdatagrid

[![Docs](https://img.shields.io/badge/docs-latest-blue.svg)](https://maxfordham.github.io/xlsxdatagrid/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![PyPI - Version](https://img.shields.io/pypi/v/xlsxdatagrid.svg)](https://pypi.org/project/xlsxdatagrid)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xlsxdatagrid.svg)](https://pypi.org/project/xlsxdatagrid)
[![Actions status](https://github.com/maxfordham/xlsxdatagrid/workflows/CI/badge.svg)](https://github.com/maxfordham/xlsxdatagrid/actions)

-----

**Table of Contents**

- [xlsxdatagrid](#xlsxdatagrid)
  - [Installation](#installation)
  - [Develop](#develop)
  - [License](#license)

## Installation

```console
pip install https://github.com/maxfordham/xlsxdatagrid@main # TODO: release on pypi
```

## Develop

[Install `pixi`](https://pixi.sh/latest/)

```console
pixi run list #  list tasks
pixi run test #  run tests
```

## License

`xlsxdatagrid` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
